@@ -12,10 +12,8 @@ f = lambda root, filepaths=[]: list_filepaths(root, filepaths, is_pyfile)
 temp_dir_0 = './_list_pyfilepaths'
 temp_dir_1 = f'{temp_dir_0}/_'
 temp_files_and_content = [
-  (f'{temp_dir_0}/foo.py', 'foo'),
-  (f'{temp_dir_0}/xyz.txt', 'xyz'),
-  (f'{temp_dir_1}/abc.txt', 'abc'),
-  (f'{temp_dir_1}/bar.py', 'bar'),
+  (f'{temp_dir_0}/foo.py', 'foo'), (f'{temp_dir_0}/xyz.txt', 'xyz'),
+  (f'{temp_dir_1}/abc.txt', 'abc'), (f'{temp_dir_1}/bar.py', 'bar'),
 ]
 
 def setup():
@@ -24,16 +22,13 @@ def setup():
 
 def tear_down():
   [remove(filename) for (filename, _) in temp_files_and_content]
-  remove_dir(temp_dir_1)
-  remove_dir(temp_dir_0)
+  [remove_dir(d) for d in [temp_dir_1, temp_dir_0]]
 
 def t():
   setup()
-  expectation = set([
-    './_list_pyfilepaths/_/bar.py',
-    './_list_pyfilepaths/foo.py'
-  ])
-  observation = set(f(temp_dir_0, []))
-  test_result = expectation == observation
+  test_result = set([
+    f'{temp_dir_1}/bar.py',
+    f'{temp_dir_0}/foo.py'
+  ]) == set(f(temp_dir_0, []))
   tear_down()
   return test_result
