@@ -4,10 +4,9 @@ from re import L
 from jft.nop_x import f as nop_x
 from jft.directory.remove import f as remove
 
-def f(x='./jft.classes'):
+def f(x='./jft/classes'):
   if exists(x):
     return nop_x(x)
-
   try:
     mkdir(x)
   except FileNotFoundError as fe:
