@@ -8,7 +8,7 @@ def f(filename):
   with open(filename, 'r', encoding='utf8') as φ:
     return φ.read()
 
-temp_dir_0 = './_'
+temp_dir_0 = './_temp_file_load'
 temp_files_and_content = [(f'{temp_dir_0}/foo.py', 'foo')]
 
 def setup():
@@ -21,8 +21,6 @@ def tear_down():
 
 def t():
   setup()
-  expectation = 'foo'
-  observation = f(f'{temp_dir_0}/foo.py')
-  test_result = expectation == observation
+  test_result = 'foo' == f(f'{temp_dir_0}/foo.py')
   tear_down()
   return test_result
\ No newline at end of file
